@@ -75,7 +75,7 @@ class Domoticz(IPlugin):
 		if jsonInput['outcome']['entities']['local_search_query']['value'] :
 			local = jsonInput['outcome']['entities']['local_search_query']['value']
 		else:
-			local = "pas de local_search_query"
+			local_search_query = "pas de local_search_query"
 			bodies = ""
 #
 		idex= local + " " + location +  "_"
